package DTL::Fast::Template::Filters;
use strict; use utf8; use warnings FATAL => 'all'; 

# built in filters
use DTL::Fast::Template::Filter::Add;
use DTL::Fast::Template::Filter::Addslashes;
use DTL::Fast::Template::Filter::Capfirst;
use DTL::Fast::Template::Filter::Center;
use DTL::Fast::Template::Filter::Cut;
use DTL::Fast::Template::Filter::Date;
use DTL::Fast::Template::Filter::Default;
use DTL::Fast::Template::Filter::DefaultIfNone;
use DTL::Fast::Template::Filter::Dictsort;
use DTL::Fast::Template::Filter::Dictsortreversed;
use DTL::Fast::Template::Filter::Divisibleby;
use DTL::Fast::Template::Filter::Escape;
use DTL::Fast::Template::Filter::Escapejs;
use DTL::Fast::Template::Filter::Filesizeformat;
use DTL::Fast::Template::Filter::First;
use DTL::Fast::Template::Filter::Floatformat;
use DTL::Fast::Template::Filter::Getdigit;
use DTL::Fast::Template::Filter::Iriencode;
use DTL::Fast::Template::Filter::Join;
use DTL::Fast::Template::Filter::Last;
use DTL::Fast::Template::Filter::Length;
use DTL::Fast::Template::Filter::Lengthis;
use DTL::Fast::Template::Filter::Linebreaks;
use DTL::Fast::Template::Filter::Linebreaksbr;
use DTL::Fast::Template::Filter::Linenumbers;
use DTL::Fast::Template::Filter::Ljust;
use DTL::Fast::Template::Filter::Lower;
use DTL::Fast::Template::Filter::MakeList;
use DTL::Fast::Template::Filter::PhoneToNumeric;
use DTL::Fast::Template::Filter::Pluralize;
use DTL::Fast::Template::Filter::Random;
use DTL::Fast::Template::Filter::Removetags;
use DTL::Fast::Template::Filter::Reverse;
use DTL::Fast::Template::Filter::Rjust;
use DTL::Fast::Template::Filter::Safe;
use DTL::Fast::Template::Filter::SafeSeq;
use DTL::Fast::Template::Filter::Slice;
use DTL::Fast::Template::Filter::Slugify;
use DTL::Fast::Template::Filter::Stringformat;
use DTL::Fast::Template::Filter::Striptags;
use DTL::Fast::Template::Filter::Time;
use DTL::Fast::Template::Filter::Timesince;
use DTL::Fast::Template::Filter::Timeuntil;
use DTL::Fast::Template::Filter::Title;
use DTL::Fast::Template::Filter::Truncatechars;
use DTL::Fast::Template::Filter::Truncatecharshtml;
use DTL::Fast::Template::Filter::Truncatewords;
use DTL::Fast::Template::Filter::Truncatewordshtml;
use DTL::Fast::Template::Filter::Unorderedlist;
use DTL::Fast::Template::Filter::Upper;
use DTL::Fast::Template::Filter::Urlencode;
use DTL::Fast::Template::Filter::Urlize;
use DTL::Fast::Template::Filter::Urlizetrunc;
use DTL::Fast::Template::Filter::Wordcount;
use DTL::Fast::Template::Filter::Wordwrap;
use DTL::Fast::Template::Filter::Yesno;


1;
